<?php

use Illuminate\Http\JsonResponse;
use Illuminate\Support\Collection;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;

function getLanguage(): string
{
    $lang = request()->header('Accept-Language');
    if (!in_array($lang, ['ja', 'en', 'hk'])) {
        $lang = 'cn';
    }
    return $lang;
}

/**
 * 失败响应
 * @param int $code
 * @return JsonResponse
 */
function fail(int $code): JsonResponse
{
    return response()->json([
        'code' => $code,
        'message' => GetErrorMessage($code, getLanguage())
    ], 417);
}

/**
 * 正常响应
 * @param Collection $data
 * @return JsonResponse
 */
function success(Collection $data): JsonResponse
{
    return response()->json($data);
}

/**
 * 参数响应
 * @param array $errors
 * @return JsonResponse
 */
function parameter(array $errors): JsonResponse
{
    return response()->json(['errors' => $errors], 400);
}

/**
 * 错误响应
 * @param int $status
 * @param string $error
 * @return JsonResponse
 */
function error(int $status, string $error): JsonResponse
{
    return response()->json(['error' => $error], $status);
}

/**
 * 获取订单号
 * @return string
 * @throws Exception
 */
function getOrderNumber(): string
{
    $carbon = new Carbon();
    $parse = $carbon::parse('2021-06-01 00:00:00');
    $day = $parse->diffInDays($carbon::now());
    $prefix = str_pad($day, 5, '0', STR_PAD_LEFT);
    $pow = pow(10, 10);
    $random_int = random_int(0, $pow - 1);
    return $prefix . str_pad($random_int, 10, '0', STR_PAD_LEFT);
}

/**
 * 获取毫秒时间戳
 * @return string
 */
function getMicroTime(): string
{
    return bcmul(microtime(true), 1000);
}

/**
 * @param string $ip
 * @param string $type
 * * @return string|bool
 * @note: 获取ip地址信息
 * @throws Exception
 * @author: fanete
 * @time: 2021/7/28 11:24 下午
 */
function getIpInfo(string $ip, string $type = 'all'): string|bool
{

    $ip2region = new Ip2Region();
    try {
        $info = $ip2region->btreeSearch($ip);
        if ($info) {
            $region = explode('|', $info['region']);
            return match ($type) {
                'country' => $region[0],
                'province' => $region[2],
                'city' => $region[3],
                'detail' => $region[4],
                default => json_encode($region),
            };
        } else {
            return false;
        }
    } catch (Exception) {
        return false;
    }
}

function printSQL()
{
    DB::listen(function ($query) {
        $bindings = $query->bindings;
        $sql = $query->sql;
        foreach ($bindings as $replace) {
            $value = is_numeric($replace) ? $replace : "'" . $replace . "'";
            $sql = preg_replace('/\?/', $value, $sql, 1);
        }
        dump($sql);
    });
}


